emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/realgud 22dd627 2/3: Get ready for release 1.5.0


From: Rocky Bernstein
Subject: [elpa] externals/realgud 22dd627 2/3: Get ready for release 1.5.0
Date: Tue, 28 May 2019 14:01:13 -0400 (EDT)

branch: externals/realgud
commit 22dd6278b8a4d61b43215c0c4d42b323036bb5b7
Author: rocky <address@hidden>
Commit: rocky <address@hidden>

    Get ready for release 1.5.0
---
 README.md                              |   2 +-
 configure.ac                           |   2 -
 realgud.el                             |   3 -
 realgud/common/buffer/command.el       |   4 +-
 realgud/common/core.el                 |   5 --
 realgud/common/eval.el                 |   2 +-
 realgud/common/follow.el               |   7 +-
 realgud/common/fringe.el               |   4 +-
 realgud/debugger/Makefile.am           |   2 +-
 realgud/debugger/bashdb/Makefile.am    |   3 +
 realgud/debugger/bashdb/bashdb.el      |   4 +-
 realgud/debugger/gdb/gdb.el            |   2 +-
 realgud/debugger/kshdb/Makefile.am     |   3 +
 realgud/debugger/pdb/Makefile.am       |   3 +
 realgud/debugger/rdebug/rdebug.el      |   4 +-
 realgud/debugger/remake/remake.el      |   4 +-
 realgud/debugger/trepan.pl/trepanpl.el |   2 +-
 realgud/debugger/trepan/trepan.el      |   4 +-
 realgud/debugger/trepan2/trepan2.el    |   4 +-
 realgud/debugger/trepan3k/trepan3k.el  |   4 +-
 realgud/debugger/trepanjs/trepanjs.el  |   4 +-
 realgud/debugger/zshdb/Makefile.am     |   3 +
 realgud/debugger/zshdb/zshdb.el        |   4 +-
 test/test-ipdb.el                      |  40 ------------
 test/test-jdb.el                       |  18 ------
 test/test-loc-regexp-nodejs.el         | 115 ---------------------------------
 test/test-nodejs.el                    |  37 -----------
 test/test-regexp-ipdb.el               | 108 -------------------------------
 test/test-regexp-jdb.el                |  78 ----------------------
 test/test-regexp-nodejs.el             |  74 ---------------------
 test/test-shortkey.el                  |  10 +--
 31 files changed, 46 insertions(+), 513 deletions(-)

diff --git a/README.md b/README.md
index 498fcd8..82914ef 100644
--- a/README.md
+++ b/README.md
@@ -1,4 +1,4 @@
-[![Build Status][travis-image]][travis-url]
+<!-- [![Build Status][travis-image]][travis-url] -->
 [![MELPA][melpa-image]][melpa]
 [![MELPA Stable][melpa-stable-image]][melpa-stable]
 
diff --git a/configure.ac b/configure.ac
index cfa1433..6388c31 100644
--- a/configure.ac
+++ b/configure.ac
@@ -66,9 +66,7 @@ AC_CONFIG_FILES([Makefile \
                 realgud/debugger/bashdb/Makefile \
                 realgud/debugger/gdb/Makefile \
                 realgud/debugger/gub/Makefile \
-                realgud/debugger/ipdb/Makefile \
                 realgud/debugger/kshdb/Makefile \
-                realgud/debugger/nodejs/Makefile \
                 realgud/debugger/perldb/Makefile \
                 realgud/debugger/pdb/Makefile \
                 realgud/debugger/rdebug/Makefile \
diff --git a/realgud.el b/realgud.el
index 93c30e4..743efd7 100644
--- a/realgud.el
+++ b/realgud.el
@@ -99,10 +99,7 @@
        "./realgud/debugger/bashdb/bashdb"
        "./realgud/debugger/gdb/gdb"
        "./realgud/debugger/gub/gub"
-       "./realgud/debugger/ipdb/ipdb"
-       "./realgud/debugger/jdb/jdb"
        "./realgud/debugger/kshdb/kshdb"
-       "./realgud/debugger/nodejs/nodejs"
        "./realgud/debugger/pdb/pdb"
        "./realgud/debugger/perldb/perldb"
        "./realgud/debugger/rdebug/rdebug"
diff --git a/realgud/common/buffer/command.el b/realgud/common/buffer/command.el
index 200fc8c..e910e77 100644
--- a/realgud/common/buffer/command.el
+++ b/realgud/common/buffer/command.el
@@ -49,13 +49,13 @@
     (t (:weight bold)))
   "Face used to highlight debugger run information."
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 (defface debugger-not-running
   '((t :inherit font-lock-warning-face))
   "Face used when debugger or process is not running."
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 
 (cl-defstruct realgud-cmdbuf-info
diff --git a/realgud/common/core.el b/realgud/common/core.el
index 25de3d7..9766e99 100644
--- a/realgud/common/core.el
+++ b/realgud/common/core.el
@@ -14,11 +14,6 @@
 
 ;; (require 'term)
 
-(if (< emacs-major-version 24)
-    (error
-     "You need at least Emacs 24 or greater to run this - you have version %d"
-     emacs-major-version))
-
 (require 'comint)
 (require 'load-relative)
 (require 'loc-changes)
diff --git a/realgud/common/eval.el b/realgud/common/eval.el
index 1ba52a4..efcc530 100644
--- a/realgud/common/eval.el
+++ b/realgud/common/eval.el
@@ -4,7 +4,7 @@
 ;; Version: 1.1
 ;; Keywords: internal
 ;; URL: http://github.com/rocky/emacs-load-relative
-;; Compatibility: GNU Emacs 24.x
+;; Compatibility: GNU Emacs 25.x
 
 ;; Copyright (C) 2015 Free Software Foundation, Inc
 
diff --git a/realgud/common/follow.el b/realgud/common/follow.el
index 12cf2c2..e22341f 100644
--- a/realgud/common/follow.el
+++ b/realgud/common/follow.el
@@ -1,4 +1,4 @@
-;; Copyright (C) 2015 Free Software Foundation, Inc
+;; Copyright (C) 2015, 2019 Free Software Foundation, Inc
 
 ;; Author: Rocky Bernstein <address@hidden>
 
@@ -15,8 +15,9 @@
 ;;; Follows or goto's something
 (require 'load-relative)
 
-(declare-function realgud:cmd-frame 'realgud-cmds)
-(declare-function realgud-loc-p     'realgud-loc)
+(declare-function realgud:cmd-frame  'realgud-cmds)
+(declare-function realgud-loc-marker 'realgud-loc)
+(declare-function realgud-loc-p      'realgud-loc)
 
 (defun realgud:follow-mark(mark)
   (when (markerp mark)
diff --git a/realgud/common/fringe.el b/realgud/common/fringe.el
index b3ee9eb..4fe43fb 100644
--- a/realgud/common/fringe.el
+++ b/realgud/common/fringe.el
@@ -38,13 +38,13 @@
     (t (:weight bold)))
   "Face used to highlight debugger run information."
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 (defface realgud-debugger-not-running
   '((t :inherit font-lock-warning-face))
   "Face used when debugger or process is not running."
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 
 ;; FIXME: Figure out how to do this as a macro.
diff --git a/realgud/debugger/Makefile.am b/realgud/debugger/Makefile.am
index e001fce..0075613 100644
--- a/realgud/debugger/Makefile.am
+++ b/realgud/debugger/Makefile.am
@@ -1,5 +1,5 @@
 SUBDIRS = \
-       bashdb gdb gub kshdb nodejs \
+       bashdb gdb gub kshdb \
        pdb perldb rdebug remake \
        trepan trepan2 trepan3k trepan.pl \
        zshdb
diff --git a/realgud/debugger/bashdb/Makefile.am 
b/realgud/debugger/bashdb/Makefile.am
index e6c68b4..d4ff8d7 100644
--- a/realgud/debugger/bashdb/Makefile.am
+++ b/realgud/debugger/bashdb/Makefile.am
@@ -3,3 +3,6 @@ include ../common.mk
 lisp_files = $(wildcard *.el)
 lisp_LISP = $(lisp_files)
 EXTRA_DIST = $(lisp_files)
+
+bashdb.elc: core.elc track-mode.elc
+track-mode.elc: core.elc init.elc
diff --git a/realgud/debugger/gdb/gdb.el b/realgud/debugger/gdb/gdb.el
index c6a4d17..e8c3953 100644
--- a/realgud/debugger/gdb/gdb.el
+++ b/realgud/debugger/gdb/gdb.el
@@ -37,7 +37,7 @@
 (defgroup realgud:gdb nil
   "The realgud interface to gdb"
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 ;; -------------------------------------------------------------------
 ;; User definable variables
diff --git a/realgud/debugger/kshdb/Makefile.am 
b/realgud/debugger/kshdb/Makefile.am
index e6c68b4..84b5877 100644
--- a/realgud/debugger/kshdb/Makefile.am
+++ b/realgud/debugger/kshdb/Makefile.am
@@ -3,3 +3,6 @@ include ../common.mk
 lisp_files = $(wildcard *.el)
 lisp_LISP = $(lisp_files)
 EXTRA_DIST = $(lisp_files)
+
+kshdb.elc: core.elc track-mode.elc
+track-mode.elc: core.elc init.elc
diff --git a/realgud/debugger/pdb/Makefile.am b/realgud/debugger/pdb/Makefile.am
index e6c68b4..88b0a9f 100644
--- a/realgud/debugger/pdb/Makefile.am
+++ b/realgud/debugger/pdb/Makefile.am
@@ -3,3 +3,6 @@ include ../common.mk
 lisp_files = $(wildcard *.el)
 lisp_LISP = $(lisp_files)
 EXTRA_DIST = $(lisp_files)
+
+pshd.elc: core.elc track-mode.elc
+track-mode.elc: core.elc init.elc
diff --git a/realgud/debugger/trepan.pl/trepanpl.el 
b/realgud/debugger/trepan.pl/trepanpl.el
index 689c03d..2285b4b 100644
--- a/realgud/debugger/trepan.pl/trepanpl.el
+++ b/realgud/debugger/trepan.pl/trepanpl.el
@@ -20,7 +20,7 @@
   "The realgud interface to the Perl \"trepanning\" debugger"
   :group 'perl
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 ;; -------------------------------------------------------------------
 ;; User definable variables
diff --git a/realgud/debugger/zshdb/Makefile.am 
b/realgud/debugger/zshdb/Makefile.am
index e6c68b4..9905e84 100644
--- a/realgud/debugger/zshdb/Makefile.am
+++ b/realgud/debugger/zshdb/Makefile.am
@@ -3,3 +3,6 @@ include ../common.mk
 lisp_files = $(wildcard *.el)
 lisp_LISP = $(lisp_files)
 EXTRA_DIST = $(lisp_files)
+
+zshdb.elc: core.elc track-mode.elc
+track-mode.elc: core.elc init.elc
diff --git a/test/test-ipdb.el b/test/test-ipdb.el
deleted file mode 100644
index 77b32aa..0000000
--- a/test/test-ipdb.el
+++ /dev/null
@@ -1,40 +0,0 @@
-;; Press C-x C-e at the end of the next line to run this file test 
non-interactively
-;; (test-simple-run "emacs -batch -L %s -l %s" (file-name-directory 
(locate-library "test-simple.elc")) buffer-file-name)
-
-(require 'test-simple)
-(require 'load-relative)
-(load-file "../realgud/debugger/ipdb/ipdb.el")
-
-(eval-when-compile (defvar test:run-process-save))
-
-(declare-function ipdb-parse-cmd-args 'realgud:ipdb-core)
-(declare-function realgud:ipdb        'realgud:ipdb)
-(declare-function __FILE__            'load-relative)
-
-(test-simple-start)
-
-;; Save value realgud:run-process and change it to something we want
-(setq test:run-process-save (symbol-function 'realgud:run-process))
-(defun realgud:run-process(debugger-name script-filename cmd-args
-                                     minibuffer-histroy &optional no-reset)
-  "Fake realgud:run-process used in testing"
-  (note
-   (format "%s %s %s" debugger-name script-filename cmd-args))
-  (assert-equal "ipdb" debugger-name "debugger name gets passed")
-  (assert-equal (expand-file-name "./gcd.py") script-filename "file name 
check")
-  (assert-equal '("3" "5") (cddr cmd-args) "command args listified")
-  (generate-new-buffer "*cmdbuf-test*")
-  )
-
-(note "ipdb-parse-cmd-args")
-(assert-equal (list nil '("ipdb") (list (expand-file-name "foo")) nil)
-             (ipdb-parse-cmd-args '("ipdb" "foo")))
-(assert-equal (list nil '("ipdb") (list (expand-file-name "program.py") "foo") 
nil)
-             (ipdb-parse-cmd-args
-              '("ipdb" "program.py" "foo")))
-
-(realgud:ipdb "ipdb ./gcd.py 3 5")
-;; Restore the old value of realgud:run-process
-(fset 'realgud:run-process test:run-process-save)
-
-(end-tests)
diff --git a/test/test-jdb.el b/test/test-jdb.el
deleted file mode 100644
index 881b60d..0000000
--- a/test/test-jdb.el
+++ /dev/null
@@ -1,18 +0,0 @@
-;; Press C-x C-e at the end of the next line to run this file test 
non-interactively
-;; (test-simple-run "emacs -batch -L %s -l %s" (file-name-directory 
(locate-library "test-simple.elc")) buffer-file-name)
-
-(require 'test-simple)
-(require 'load-relative)
-(load-file "../realgud/debugger/jdb/core.el")
-(test-simple-start)
-
-(declare-function __FILE__  'load-relative)
-(declare-function realgud:jdb-parse-cmd-args 'realgud:jdb-core)
-(declare-function realgud:jdb-dot-to-slash   'realgud:jdb-core)
-
-(assert-equal '("jdb" nil ("./TestMe.java"))
-             (realgud:jdb-parse-cmd-args '("jdb" "./TestMe.java")))
-(assert-equal "mcb/pcingola/SnpEff/main"
-             (realgud:jdb-dot-to-slash "mcb.pcingola.SnpEff.main"))
-
-(end-tests)
diff --git a/test/test-loc-regexp-nodejs.el b/test/test-loc-regexp-nodejs.el
deleted file mode 100644
index f9b647d..0000000
--- a/test/test-loc-regexp-nodejs.el
+++ /dev/null
@@ -1,115 +0,0 @@
-;; Press C-x C-e at the end of the next line to run this file test 
non-interactively
-;; (test-simple-run "emacs -batch -L %s -l %s" (file-name-directory 
(locate-library "test-simple.elc")) buffer-file-name)
-
-(load-file "./regexp-helper.el")
-(load-file "../realgud/common/regexp.el")
-(load-file "../realgud/debugger/nodejs/init.el")
-
-(declare-function realgud-cmdbuf-info-loc-regexp 'realgud-buffer-command)
-(declare-function cmdbuf-loc-match               'realgud-regexp-helper)
-(declare-function realgud-loc-pat-regexp         'realgud-regexp)
-(declare-function realgud-loc-pat-file-group     'realgud-regexp)
-(declare-function realgud-loc-pat-line-group     'realgud-regexp)
-(declare-function realgud-cmdbuf-info-file-group 'realgud-regexp)
-(declare-function realgud-cmdbuf-info-line-group 'realgud-regexp)
-(declare-function realgud-cmdbuf-info            'realgud-regexp)
-(declare-function make-realgud-cmdbuf-info       'realgud-regexp)
-(declare-function realgud-loc-pat-num            'realgud-regexp)
-(declare-function test-simple-start 'test-simple)
-(declare-function assert-t 'test-simple)
-(declare-function assert-equal 'test-simple)
-(declare-function note 'test-simple)
-(declare-function end-tests 'test-simple)
-(declare-function realgud-loc-pat-char-offset-group  'realgud:nodejs-init)
-
-(test-simple-start)
-
-(eval-when-compile
-  (defvar file-group)
-  (defvar frame-re)
-  (defvar line-group)
-  (defvar num-group)
-  (defvar col-group)
-  (defvar test-pos)
-  (defvar bt-re)
-  (defvar dbg-name)
-  (defvar realgud-pat-hash)
-  (defvar loc-pat)
-  (defvar test-dbgr)
-  (defvar test-s1)
-  (defvar realgud-pat-bt)
-  (defvar realgud:nodejs-pat-hash)
-)
-
-; Some setup usually done in setting up the buffer.
-; We customize this for the debugger trepan. Others may follow.
-; FIXME: encapsulate this.
-(setq dbg-name "nodejs")
-(setq loc-pat (gethash "loc" (gethash dbg-name realgud-pat-hash)))
-
-(setq test-dbgr (make-realgud-cmdbuf-info
-                :debugger-name dbg-name
-                :loc-regexp (realgud-loc-pat-regexp loc-pat)
-                :file-group (realgud-loc-pat-file-group loc-pat)
-                :line-group (realgud-loc-pat-line-group loc-pat)))
-
-
-(note "debugger-backtrace")
-(setq realgud-pat-bt  (gethash "debugger-backtrace"
-                            realgud:nodejs-pat-hash))
-(setq test-s1
-      "#0 module.js:380:17
-#1 Module._compile module2.js:456:26
-#2 Module._extensions..js module.js:474:10
-#3 Module.load module.js:356:32
-")
-
-(setq bt-re (realgud-loc-pat-regexp realgud-pat-bt))
-(setq num-group (realgud-loc-pat-num realgud-pat-bt))
-(setq file-group (realgud-loc-pat-file-group realgud-pat-bt))
-(setq line-group (realgud-loc-pat-line-group realgud-pat-bt))
-(setq col-group (realgud-loc-pat-char-offset-group realgud-pat-bt))
-(assert-equal 0 (string-match bt-re test-s1))
-(assert-equal "0" (substring test-s1
-                            (match-beginning num-group)
-                            (match-end num-group)))
-(assert-equal "module.js"
-             (substring test-s1
-                        (match-beginning file-group)
-                        (match-end file-group)))
-(assert-equal "380"
-             (substring test-s1
-                        (match-beginning line-group)
-                        (match-end line-group)))
-(assert-equal "17" (substring test-s1
-                            (match-beginning col-group)
-                            (match-end col-group)))
-
-(setq test-pos (match-end 0))
-(assert-equal 19 (string-match bt-re test-s1 test-pos))
-
-(setq test-s1
-      "#1 Module._compile module2.js:456:26
-#2 Module._extensions..js module.js:474:10
-#3 Module.load module.js:356:32
-")
-(assert-equal 0 (string-match bt-re test-s1))
-
-(assert-equal "1" (substring test-s1
-                            (match-beginning num-group)
-                            (match-end num-group)))
-(assert-equal "module2.js"
-             (substring test-s1
-                        (match-beginning file-group)
-                        (match-end file-group)))
-(assert-equal "456"
-             (substring test-s1
-                        (match-beginning line-group)
-                        (match-end line-group)))
-(assert-equal "26" (substring test-s1
-                             (match-beginning col-group)
-                             (match-end col-group)))
-(setq test-pos (match-end 0))
-(assert-equal 36 test-pos)
-
-(end-tests)
diff --git a/test/test-nodejs.el b/test/test-nodejs.el
deleted file mode 100644
index e6ab3bb..0000000
--- a/test/test-nodejs.el
+++ /dev/null
@@ -1,37 +0,0 @@
-;; Press C-x C-e at the end of the next line to run this file test 
non-interactively
-;; (test-simple-run "emacs -batch -L %s -l %s" (file-name-directory 
(locate-library "test-simple.elc")) buffer-file-name)
-
-(require 'test-simple)
-(load-file "../realgud/debugger/nodejs/nodejs.el")
-
-(eval-when-compile (defvar test:run-process-save))
-
-(declare-function nodejs-parse-cmd-args 'realgud:nodejs)
-(declare-function nodejs                'realgud:nodejs)
-(declare-function __FILE__              'load-relative)
-
-(test-simple-start)
-
-;; Save value realgud:run-process and change it to something we want
-(setq test:run-process-save (symbol-function 'realgud:run-process))
-(defun realgud:run-process(debugger-name script-filename cmd-args
-                                        minibuf-history &optional no-reset)
-  "Fake realgud:run-process used in testing"
-  (note
-   (format "%s %s %s" debugger-name script-filename cmd-args))
-  (assert-equal "node" debugger-name "debugger name gets passed")
-  (let ((expanded-name (expand-file-name "./gcd.js")))
-    (assert-equal  expanded-name script-filename "file name check")
-    ))
-
-(note "nodejs-parse-cmd-args")
-(assert-equal (list '("node" "debug") nil '("foo"))
-             (nodejs-parse-cmd-args '("node" "debug" "foo")))
-
-;; FIXME: need to mock remove-ansi-schmutz in realgud:nodejs
-;; (realgud:nodejs "node debug ./gcd.js 3 5")
-
-;; Restore the old value of realgud:run-process
-(fset 'realgud:run-process test:run-process-save)
-
-(end-tests)
diff --git a/test/test-regexp-ipdb.el b/test/test-regexp-ipdb.el
deleted file mode 100644
index a9a74cc..0000000
--- a/test/test-regexp-ipdb.el
+++ /dev/null
@@ -1,108 +0,0 @@
-;; Press C-x C-e at the end of the next line to run this file test 
non-interactively
-;; (test-simple-run "emacs -batch -L %s -l %s" (file-name-directory 
(locate-library "test-simple.elc")) buffer-file-name)
-
-(require 'test-simple)
-(load-file "../realgud/debugger/ipdb/init.el")
-(load-file "./regexp-helper.el")
-
-(declare-function __FILE__                       'load-relative)
-(declare-function loc-match                     'realgud-helper)
-(declare-function prompt-match                   'regexp-helper)
-(declare-function realgud-loc-pat-file-group     'realgud-regexp)
-(declare-function realgud-loc-pat-line-group     'realgud-regexp)
-
-(test-simple-start)
-
-(eval-when-compile
-  (defvar loc-pat)   (defvar prompt-pat) (defvar realgud:ipdb-pat-hash)
-  (defvar tb-pat)    (defvar test-text)  (defvar prompt-str)
-  (defvar bps-pat)
-)
-
-(set (make-local-variable 'bps-pat)
-      (gethash "brkpt-set" realgud:ipdb-pat-hash))
-
-(set (make-local-variable 'loc-pat)
-     (gethash "loc"       realgud:ipdb-pat-hash))
-
-(set (make-local-variable 'prompt-pat)
-      (gethash "prompt"    realgud:ipdb-pat-hash))
-
-(set (make-local-variable 'tb-pat)
-      (gethash "lang-backtrace" realgud:ipdb-pat-hash))
-
-;; FIXME: we get a void variable somewhere in here when running
-;;        even though we define it in lexical-let. Dunno why.
-;;        setq however will workaround this.
-(setq test-text
-      "  File \"/usr/lib/python2.6/code.py\", line 281, in raw_input")
-(note "traceback location matching")
-
-(assert-t (numberp (loc-match test-text tb-pat)) "basic traceback location")
-
-(assert-equal "/usr/lib/python2.6/code.py"
-             (match-string (realgud-loc-pat-file-group tb-pat)
-                           test-text))
-
-(setq test-text
-      "  File \"/usr/lib/python2.6/code.py\", line 281, in raw_input")
-(loc-match test-text tb-pat)
-(assert-equal "281"
-             (match-string (realgud-loc-pat-line-group tb-pat)
-                           test-text) "extract line number")
-
-(note "breakpoint location matching")
-
-(setq test-text "Breakpoint 1 at /src/git/code/gcd.py:13")
-(assert-t (numberp (loc-match test-text bps-pat))
-         "basic breakpoint location")
-
-(assert-equal "/src/git/code/gcd.py"
-             (match-string (realgud-loc-pat-file-group
-                            bps-pat)
-                           test-text)
-             "extract breakpoint file name")
-
-
-(assert-equal "13"
-             (match-string (realgud-loc-pat-line-group
-                            bps-pat)
-                           test-text)   "extract breakpoint line number")
-
-;; (set test-text "(c:\\working\\python\\helloworld.py:30): <module>")
-;;
-;; (assert-t (numberp (loc-match test-text loc-pat)) "MS DOS position 
location")
-;; ;;
-;; (assert-equal "c:\\working\\python\\helloworld.py"
-;;     (match-string (realgud-loc-pat-file-group loc-pat)
-;;                   test-text)
-;;     (format "Failing file group is %s"
-;;                             (realgud-loc-pat-file-group tb-pat))
-;;     "extract file name")
-;; (assert-equal "30"
-;;           (match-string (realgud-loc-pat-line-group loc-pat)
-;;                         test-text) "extract line number")
-
-(setq test-text "> /usr/bin/ipython(24)<module>")
-(assert-t (numberp (loc-match test-text loc-pat)) "position location")
-(assert-equal "/usr/bin/ipython"
-             (match-string (realgud-loc-pat-file-group loc-pat)
-                           test-text)
-             (format "Failing file group is %s"
-                     (realgud-loc-pat-file-group tb-pat)))
-(assert-equal "24"
-             (match-string (realgud-loc-pat-line-group
-                            loc-pat)
-                           test-text)
-             "extract line number")
-
-
-(note "prompt matching")
-(set (make-local-variable 'prompt-str) "ipdb> ")
-(prompt-match prompt-str nil "debugger prompt: %s")
-(setq prompt-str "ipdb")
-(assert-nil (numberp (loc-match prompt-str prompt-pat))
-           (format "%s %s" "invalid debugger prompt"
-                   prompt-str))
-
-(end-tests)
diff --git a/test/test-regexp-jdb.el b/test/test-regexp-jdb.el
deleted file mode 100644
index efac100..0000000
--- a/test/test-regexp-jdb.el
+++ /dev/null
@@ -1,78 +0,0 @@
-;; Press C-x C-e at the end of the next line to run this file test 
non-interactively
-;; (test-simple-run "emacs -batch -L %s -l %s" (file-name-directory 
(locate-library "test-simple.elc")) buffer-file-name)
-
-(require 'test-simple)
-(load-file "../realgud/common/buffer/command.el")
-(load-file "../realgud/debugger/jdb/init.el")
-(load-file "./regexp-helper.el")
-
-(declare-function __FILE__              'load-relative)
-(declare-function prompt-match          'regexp-helper)
-
-(eval-when-compile
-  (defvar dbg-name)   (defvar realgud-pat-hash)   (defvar loc-pat)
-  (defvar test-dbgr)  (defvar test-text)         (defvar prompt-pat)
-  (defvar realgud:jdb-pat-hash)
-)
-
-(test-simple-start)
-
-(note "jdb prompt matching")
-(set (make-local-variable 'prompt-pat)
-     (gethash "prompt" realgud:jdb-pat-hash))
-(prompt-match "main[1] "  "1" "most common main prompt")
-(prompt-match "main[2] "  "2" "main prompt up a level")
-(prompt-match "> " nil "no loc prompt")
-
-
-; Some setup usually done in setting up the buffer.
-; We customize this for this debugger.
-; FIXME: encapsulate this.
-(setq dbg-name "jdb")
-
-(setq loc-pat (gethash "loc" (gethash dbg-name realgud-pat-hash)))
-(setq test-dbgr (make-realgud-cmdbuf-info
-                :debugger-name dbg-name
-                :loc-regexp (realgud-loc-pat-regexp loc-pat)
-                :file-group (realgud-loc-pat-file-group loc-pat)
-                :line-group (realgud-loc-pat-line-group loc-pat)))
-
-;; FIXME: we get a void variable somewhere in here when running
-;;        even though we define it in lexical-let. Dunno why.
-;;        setq however will workaround this.
-(let ((text "Breakpoint hit: \"thread=main\", TestMe.main(), line=7 bci=0"))
-
-  (note "traceback location matching")
-
-  (assert-t (numberp (cmdbuf-loc-match text test-dbgr)) "breakpoint location")
-  (assert-equal "7"
-             (match-string (realgud-cmdbuf-info-line-group test-dbgr)
-                           text) "extract line number from breakpoint"))
-
-(let ((text "Step completed: \"thread=main\", TestMe.main(), line=71 bci=0"))
-  (assert-t (numberp (cmdbuf-loc-match text test-dbgr)) "breakpoint location")
-  (assert-equal "71"
-               (match-string (realgud-cmdbuf-info-line-group test-dbgr)
-                             text) "extract line number from step"))
-
-;; (note "debugger-backtrace")
-;; (setq realgud-bt-pat  (gethash "debugger-backtrace"
-;;                         realgud:jdb-pat-hash))
-;; (setq s1
-;;       "  [1] java.lang.Class.getDeclaredMethods0 (native method)
-;;   [2] java.lang.Class.privateGetDeclaredMethods (Class.java:2,570)
-;;   [3] java.lang.Class.getMethod0 (Class.java:2,813)
-;;   [4] java.lang.Class.getMethod (Class.java:1,663)
-;;   [5] sun.launcher.LauncherHelper.getMainMethod (LauncherHelper.java:494)
-;;   [6] sun.launcher.LauncherHelper.checkAndLoadMain (LauncherHelper.java:486)
-;; ")
-;; (setq realgud-bt-re (realgud-loc-pat-regexp realgud-bt-pat))
-;; (setq file-group (realgud-loc-pat-file-group realgud-bt-pat))
-;; (setq line-group (realgud-loc-pat-line-group realgud-bt-pat))
-;; (assert-equal 0 (string-match realgud-bt-re s1))
-;; (assert-equal "570"
-;;           (substring s1
-;;                      (match-beginning line-group)
-;;                      (match-end line-group)))
-
-(end-tests)
diff --git a/test/test-regexp-nodejs.el b/test/test-regexp-nodejs.el
deleted file mode 100644
index c4ea10d..0000000
--- a/test/test-regexp-nodejs.el
+++ /dev/null
@@ -1,74 +0,0 @@
-;; Press C-x C-e at the end of the next line to run this file test 
non-interactively
-;; (test-simple-run "emacs -batch -L %s -l %s" (file-name-directory 
(locate-library "test-simple.elc")) buffer-file-name)
-
-(require 'test-simple)
-(load-file "../realgud/debugger/nodejs/init.el")
-(load-file "./regexp-helper.el")
-
-(declare-function realgud-cmdbuf-info-loc-regexp 'realgud-buffer-command)
-(declare-function cmdbuf-loc-match               'realgud-regexp)
-(declare-function loc-match                     'realgud-helper)
-(declare-function prompt-match                   'regexp-helper)
-(declare-function realgud-loc-pat-num            'realgud-regexp)
-(declare-function realgud-loc-pat-regexp         'realgud-regexp)
-(declare-function realgud-loc-pat-file-group     'realgud-regexp)
-(declare-function realgud-loc-pat-line-group     'realgud-regexp)
-(declare-function  make-realgud-cmdbuf-info      'realgud-regexp)
-(declare-function realgud-cmdbuf-info-file-group 'realgud-regexp)
-(declare-function realgud-cmdbuf-info-line-group 'realgud-regexp)
-(declare-function __FILE__                       'load-relative)
-
-(test-simple-start)
-
-(eval-when-compile
-  (defvar dbg-name)
-  (defvar loc-pat)
-  (defvar bt-pat)
-  (defvar prompt-pat)
-  (defvar realgud:nodejs-pat-hash)
-  (defvar realgud-pat-hash)
-  (defvar test-dbgr)
-  (defvar test-text)
-  (defvar test-s1)
-)
-
-(note "nodejs prompt matching")
-(set (make-local-variable 'prompt-pat)
-     (gethash "prompt" realgud:nodejs-pat-hash))
-(prompt-match "debug> ")
-(prompt-match "debug> connecting... ok")
-
-(note "nodejs location matching")
-(setq dbg-name "nodejs")
-(setq loc-pat (gethash "loc" (gethash dbg-name realgud-pat-hash)))
-
-(setq test-dbgr (make-realgud-cmdbuf-info
-                :debugger-name dbg-name
-                :loc-regexp (realgud-loc-pat-regexp loc-pat)
-                :file-group (realgud-loc-pat-file-group loc-pat)
-                :line-group (realgud-loc-pat-line-group loc-pat)))
-
-(setq test-text "break in test/fixtures/break-in-module/main.js:1\n")
-(assert-t (numberp (cmdbuf-loc-match test-text test-dbgr)) "basic location")
-
-(string-match (realgud-cmdbuf-info-loc-regexp test-dbgr) test-text)
-(assert-equal "test/fixtures/break-in-module/main.js"
-             (match-string (realgud-cmdbuf-info-file-group test-dbgr)
-                           test-text) "extract file name")
-
-(string-match (realgud-cmdbuf-info-loc-regexp test-dbgr) test-text)
-(assert-equal "1"
-             (match-string
-              (realgud-cmdbuf-info-line-group test-dbgr)
-              test-text) "extract line number")
-
-(note "debugger-backtrace")
-(setq test-text
-    "#0 module.js:380:17
-")
-
-(set (make-local-variable
-      'bt-pat)
-      (gethash "debugger-backtrace" realgud:nodejs-pat-hash))
-
-(end-tests)
diff --git a/test/test-shortkey.el b/test/test-shortkey.el
index 5f599d9..29ee5fd 100644
--- a/test/test-shortkey.el
+++ b/test/test-shortkey.el
@@ -14,7 +14,7 @@
   (defvar debugger-name)
   (defvar realgud-pat-hash)
   (defvar test-keymap)
-  (defvar nodejs-short-key-mode-map)
+  (defvar zshdb-short-key-mode-map)
 )
 
 (declare-function __FILE__           'load-relative)
@@ -28,13 +28,13 @@
 (note "realgud-get-short-key-mode-map")
 
 (setq temp-cmdbuf (generate-new-buffer "*cmdbuf-test*"))
-(setq debugger-name "nodejs")
-(load-file "../realgud/debugger/nodejs/nodejs.el")
+(setq debugger-name "zshdb")
+(load-file "../realgud/debugger/zshdb/zshdb.el")
 (realgud-cmdbuf-init temp-cmdbuf debugger-name
                     (gethash debugger-name realgud-pat-hash))
 (setq test-keymap (realgud-get-short-key-mode-map temp-cmdbuf))
 (assert-t (keymapp test-keymap)
          "realgud-get-short-key-mode-map returns keymap")
-(assert-equal test-keymap nodejs-short-key-mode-map
-         "realgud-get-short-key-mode-map returns nodejs-short-key-mode-map")
+(assert-equal test-keymap zshdb-short-key-mode-map
+         "realgud-get-short-key-mode-map returns zshdb-short-key-mode-map")
 (end-tests)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/realgud/debugger/bashdb/bashdb.el 
b/realgud/debugger/bashdb/bashdb.el
index 1d065b9..10ae1d9 100644
--- a/realgud/debugger/bashdb/bashdb.el
+++ b/realgud/debugger/bashdb/bashdb.el
@@ -24,11 +24,11 @@
 (require-relative-list '("core" "track-mode")   "realgud:bashdb-")
 
 ;; This is needed, or at least the docstring part of it is needed to
 ;; get the customization menu to work in Emacs 24.
 (defgroup realgud:bashdb nil
   "The realgud interface to bashdb"
   :group 'realgud
-  :version "24.3")
+  :version "25.3")
 
 (declare-function realgud-command            'realgud:cmds)
 
@@ -24,11 +24,11 @@
 
 ;; This is needed, or at least the docstring part of it is needed to
-;; get the customization menu to work in Emacs 24.
+;; get the customization menu to work in Emacs 25.
 (defgroup realgud:bashdb nil
   "The realgud interface to bashdb"
diff --git a/realgud/debugger/rdebug/rdebug.el 
b/realgud/debugger/rdebug/rdebug.el
index 3abd307..7fad992 100644
--- a/realgud/debugger/rdebug/rdebug.el
+++ b/realgud/debugger/rdebug/rdebug.el
@@ -13,11 +13,11 @@
                         "../../common/track") "realgud-")
 (require-relative-list '("core" "track-mode") "realgud-rdebug-")
 ;; This is needed, or at least the docstring part of it is needed to
 ;; get the customization menu to work in Emacs 24.
 (defgroup realgud:rdebug nil
   "The realgud interface to the Ruby debugger, rdebug"
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 (declare-function rdebug-query-cmdline   'realgud-rdebug-core)
 (declare-function rdebug-parse-cmd-args  'realgud-rdebug-core)
@@ -13,11 +13,11 @@
 (require-relative-list '("core" "track-mode") "realgud-rdebug-")
 ;; This is needed, or at least the docstring part of it is needed to
-;; get the customization menu to work in Emacs 24.
+;; get the customization menu to work in Emacs 25.
 (defgroup realgud:rdebug nil
   "The realgud interface to the Ruby debugger, rdebug"
diff --git a/realgud/debugger/remake/remake.el 
b/realgud/debugger/remake/remake.el
index e07cb1b..82d86d4 100644
--- a/realgud/debugger/remake/remake.el
+++ b/realgud/debugger/remake/remake.el
@@ -22,12 +22,12 @@
 (require-relative-list '("../../common/run")    "realgud:")
 (require-relative-list '("core" "track-mode") "realgud:remake-")
 ;; This is needed, or at least the docstring part of it is needed to
 ;; get the customization menu to work in Emacs 24.
 (defgroup realgud:remake nil
   "The realgud interface to the GNU Make debugger"
   :group 'realgud
   :group 'make
-  :version "24.3")
+  :version "25.1")
 
 (eval-when-compile (require 'cl-lib))
 
@@ -22,12 +22,12 @@
 (require-relative-list '("core" "track-mode") "realgud:remake-")
 ;; This is needed, or at least the docstring part of it is needed to
-;; get the customization menu to work in Emacs 24.
+;; get the customization menu to work in Emacs 25.
 (defgroup realgud:remake nil
   "The realgud interface to the GNU Make debugger"
diff --git a/realgud/debugger/trepan/trepan.el 
b/realgud/debugger/trepan/trepan.el
index d98c129..e3b17ca 100644
--- a/realgud/debugger/trepan/trepan.el
+++ b/realgud/debugger/trepan/trepan.el
@@ -23,12 +23,12 @@
 (declare-function realgud:run-debugger 'realgud:run)
 
 ;; This is needed, or at least the docstring part of it is needed to
 ;; get the customization menu to work in Emacs 24.
 (defgroup realgud:trepan nil
   "The realgud interface to the Ruby 1.9.2 1.9.3 \"trepanning\" debugger"
   :group 'ruby
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 ;; -------------------------------------------------------------------
 ;; User-definable variables
@@ -23,12 +23,12 @@
 
 ;; This is needed, or at least the docstring part of it is needed to
-;; get the customization menu to work in Emacs 24.
+;; get the customization menu to work in Emacs 25.
 (defgroup realgud:trepan nil
   "The realgud interface to the Ruby 1.9.2 1.9.3 \"trepanning\" debugger"
diff --git a/realgud/debugger/trepan2/trepan2.el 
b/realgud/debugger/trepan2/trepan2.el
index 3b12bb3..d3e15a1 100644
--- a/realgud/debugger/trepan2/trepan2.el
+++ b/realgud/debugger/trepan2/trepan2.el
@@ -16,12 +16,12 @@
 (require-relative-list '("core" "track-mode")   "realgud:trepan2-")
 
 ;; This is needed, or at least the docstring part of it is needed to
 ;; get the customization menu to work in Emacs 24.
 (defgroup realgud:trepan2 nil
   "The realgud interface to the Python trepan2 debugger"
   :group 'realgud
   :group 'python
-  :version "24.2")
+  :version "25.1")
 
 (declare-function trepan2-query-cmdline  'realgud:trepan2-core)
 (declare-function trepan2-parse-cmd-args 'realgud:trepan2-core)
@@ -16,12 +16,12 @@
 
 ;; This is needed, or at least the docstring part of it is needed to
-;; get the customization menu to work in Emacs 24.
+;; get the customization menu to work in Emacs 25.
 (defgroup realgud:trepan2 nil
   "The realgud interface to the Python trepan2 debugger"
diff --git a/realgud/debugger/trepan3k/trepan3k.el 
b/realgud/debugger/trepan3k/trepan3k.el
index 2b473e4..7d3dc07 100644
--- a/realgud/debugger/trepan3k/trepan3k.el
+++ b/realgud/debugger/trepan3k/trepan3k.el
@@ -14,12 +14,12 @@
 (require-relative-list '("core" "track-mode") "realgud:trepan3k-")
 
 ;; This is needed, or at least the docstring part of it is needed to
 ;; get the customization menu to work in Emacs 24.
 (defgroup realgud:trepan3k nil
   "The realgud interface to the Python debugger, trepan3k"
   :group 'realgud
   :group 'python
-  :version "24.3")
+  :version "25.1")
 
 (declare-function trepan3k-query-cmdline  'realgud:trepan3k-core)
 (declare-function trepan3k-parse-cmd-args 'realgud:trepan3k-core)
@@ -14,12 +14,12 @@
 
 ;; This is needed, or at least the docstring part of it is needed to
-;; get the customization menu to work in Emacs 24.
+;; get the customization menu to work in Emacs 25.
 (defgroup realgud:trepan3k nil
   "The realgud interface to the Python debugger, trepan3k"
diff --git a/realgud/debugger/trepanjs/trepanjs.el 
b/realgud/debugger/trepanjs/trepanjs.el
index 1093fc7..8c08515 100644
--- a/realgud/debugger/trepanjs/trepanjs.el
+++ b/realgud/debugger/trepanjs/trepanjs.el
@@ -29,12 +29,12 @@
 (declare-function realgud:run-debugger 'realgud:run)
 
 ;; This is needed, or at least the docstring part of it is needed to
 ;; get the customization menu to work in Emacs 24.
 (defgroup realgud:trepanjs nil
   "The realgud interface to the Ruby 1.9.2 1.9.3 \"trepanjsning\" debugger"
   :group 'ruby
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 ;; -------------------------------------------------------------------
 ;; User-definable variables
@@ -29,12 +29,12 @@
 
 ;; This is needed, or at least the docstring part of it is needed to
-;; get the customization menu to work in Emacs 24.
+;; get the customization menu to work in Emacs 25.
 (defgroup realgud:trepanjs nil
   "The realgud interface to the Ruby 1.9.2 1.9.3 \"trepanjsning\" debugger"
diff --git a/realgud/debugger/zshdb/zshdb.el b/realgud/debugger/zshdb/zshdb.el
index 362ed39..46d83d1 100644
--- a/realgud/debugger/zshdb/zshdb.el
+++ b/realgud/debugger/zshdb/zshdb.el
@@ -19,11 +19,11 @@
 (declare-function zshdb-parse-cmd-args 'realgud:zshdb-core)
 
 ;; This is needed, or at least the docstring part of it is needed to
 ;; get the customization menu to work in Emacs 24.
 (defgroup realgud:zshdb nil
   "The realgud interface to the Zsh debugger, zshdb"
   :group 'realgud
-  :version "24.3")
+  :version "25.1")
 
 ;; -------------------------------------------------------------------
 ;; User definable variables
@@ -19,11 +19,11 @@
 
 ;; This is needed, or at least the docstring part of it is needed to
-;; get the customization menu to work in Emacs 24.
+;; get the customization menu to work in Emacs 25.
 (defgroup realgud:zshdb nil
   "The realgud interface to the Zsh debugger, zshdb"